==> v1.0.24+24.zip: fapp/lib/widgets/VideoWidget.dart <==
import 'package:flutter/material.dart';
import 'package:cached_video_player_plus/cached_video_player_plus.dart';
import 'package:cached_network_image/cached_network_image.dart';
import 'package:f0ckapp/models/MediaItem.dart';
import 'package:f0ckapp/widgets/VideoOverlay.dart';
import 'dart:async';

class VideoWidget extends StatefulWidget {
  final MediaItem details;
  const VideoWidget({super.key, required this.details});

  @override
  State createState() => _VideoWidgetState();
}

class _VideoWidgetState extends State<VideoWidget> {
  late CachedVideoPlayerPlusController _controller;
  bool _showControls = false;
  Timer? _hideControlsTimer;

  @override
  void initState() {
    super.initState();
    _initController();
  }

  Future<void> _initController() async {
    _controller = CachedVideoPlayerPlusController.networkUrl(
      Uri.parse(widget.details.mediaUrl),
    );
    await _controller.initialize();
    setState(() {});

    _controller.addListener(() => setState(() {}));
    _controller.play();
    _controller.setLooping(true);
  }

  @override
  void dispose() {
    _controller.dispose();
    _hideControlsTimer?.cancel();
    super.dispose();
  }

  void _onTap({bool ctrlButton = false}) {
    if (!ctrlButton) {
      setState(() => _showControls = !_showControls);
    }

    if (_showControls) {
      _hideControlsTimer?.cancel();
      _hideControlsTimer = Timer(Duration(seconds: 5), () {
        setState(() => _showControls = false);
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    bool isAudio = widget.details.mime.startsWith('audio');

    return Column(
      mainAxisSize: MainAxisSize.min,
      children: [
        AspectRatio(
          aspectRatio: _controller.value.isInitialized
              ? _controller.value.aspectRatio
              : 9 / 16,
          child: Stack(
            alignment: Alignment.topCenter,
            children: [
              GestureDetector(
                onTap: _onTap,
                child: isAudio
                    ? CachedNetworkImage(
                        imageUrl: widget.details.coverUrl,
                        fit: BoxFit.cover,
                        placeholder: (context, url) =>
                            CircularProgressIndicator(),
                        errorWidget: (context, url, error) => Image.asset(
                          'assets/images/music.webp',
                          fit: BoxFit.contain,
                          width: double.infinity
                        ),
                      )
                    : _controller.value.isInitialized
                    ? CachedVideoPlayerPlus(_controller)
                    : Center(child: CircularProgressIndicator()),
              ),
              if (_controller.value.isInitialized && _showControls) ...[
                IgnorePointer(
                  ignoring: true,
                  child: Container(
                    color: Colors.black.withValues(alpha: 0.5),
                    width: double.infinity,
                    height: double.infinity,
                  ),
                ),
                VideoControlsOverlay(
                  controller: _controller,
                  button: () => _onTap(ctrlButton: true),
                ),
              ],
            ],
          ),
        ),
      ],
    );
  }
}

==> v1.0.27+27.zip: fapp/lib/widgets/VideoWidget.dart <==
import 'package:flutter/material.dart';
import 'package:cached_video_player_plus/cached_video_player_plus.dart';
import 'package:cached_network_image/cached_network_image.dart';
import 'package:f0ckapp/models/MediaItem.dart';
import 'package:f0ckapp/widgets/VideoOverlay.dart';
import 'dart:async';

class VideoWidget extends StatefulWidget {
  final MediaItem details;
  final bool isActive;

  const VideoWidget({super.key, required this.details, required this.isActive});

  @override
  State createState() => _VideoWidgetState();
}

class _VideoWidgetState extends State<VideoWidget> {
  late CachedVideoPlayerPlusController _controller;
  bool _showControls = false;
  Timer? _hideControlsTimer;

  @override
  void initState() {
    super.initState();
    _initController();
  }

  Future<void> _initController() async {
    _controller = CachedVideoPlayerPlusController.networkUrl(
      Uri.parse(widget.details.mediaUrl),
    );
    await _controller.initialize();
    setState(() {});

    _controller.addListener(() => setState(() {}));
    if (widget.isActive) {
      _controller.play();
    }
    _controller.setLooping(true);
  }

  @override
  void dispose() {
    _controller.dispose();
    _hideControlsTimer?.cancel();
    super.dispose();
  }

  @override
  void didUpdateWidget(VideoWidget oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (widget.isActive) {
      _controller.play();
    } else {
      _controller.pause();
    }
  }

  void _onTap({bool ctrlButton = false}) {
    if (!ctrlButton) {
      setState(() => _showControls = !_showControls);
    }

    if (_showControls) {
      _hideControlsTimer?.cancel();
      _hideControlsTimer = Timer(Duration(seconds: 2), () {
        setState(() => _showControls = false);
      });
    }
  }

  @override
  Widget build(BuildContext context) {
    bool isAudio = widget.details.mime.startsWith('audio');

    return Column(
      mainAxisSize: MainAxisSize.min,
      children: [
        AspectRatio(
          aspectRatio: _controller.value.isInitialized
              ? _controller.value.aspectRatio
              : 9 / 16,
          child: Stack(
            alignment: Alignment.topCenter,
            children: [
              GestureDetector(
                onTap: _onTap,
                child: isAudio
                    ? CachedNetworkImage(
                        imageUrl: widget.details.coverUrl,
                        fit: BoxFit.cover,
                        placeholder: (context, url) =>
                            CircularProgressIndicator(),
                        errorWidget: (context, url, error) => Image.asset(
                          'assets/images/music.webp',
                          fit: BoxFit.contain,
                          width: double.infinity,
                        ),
                      )
                    : _controller.value.isInitialized
                    ? CachedVideoPlayerPlus(_controller)
                    : Center(child: CircularProgressIndicator()),
              ),
              if (_controller.value.isInitialized && _showControls) ...[
                IgnorePointer(
                  ignoring: true,
                  child: Container(
                    color: Colors.black.withValues(alpha: 0.5),
                    width: double.infinity,
                    height: double.infinity,
                  ),
                ),
                VideoControlsOverlay(
                  controller: _controller,
                  button: () => _onTap(ctrlButton: true),
                ),
              ],
            ],
          ),
        ),
      ],
    );
  }
}
